# flake8: noqa
from .settings import *

CACHE_MACHINE_USE_REDIS = True
REDIS_BACKEND = "redis://"
